

class NovaPHPValidator {
    provideIssues(editor) {
        let range = new Range(0, editor.document.length);
        let string = editor.getTextInRange(range);
        
        return new Promise((resolve, reject) => {
            let interpreter = nova.workspace.config.get("php.interpreter");
            if (!interpreter) {
                interpreter = "php";
            }
            
            try {
                let p = new Process(interpreter, {
                    args: ["-l"],
                    shell: nova.environment.SHELL
                });
                
                let parser = new IssueParser("php-linter");
                
                p.onStderr((line) => {
                    parser.pushLine(line);
                });
                
                p.onDidExit((code) => {
                    let issues = parser.issues;
                    resolve(issues);
                });
                
                p.start();
                
                let writer = p.stdin.getWriter();
                writer.write(string);
                writer.close();
            }
            catch (err) {
                console.error("Could not start PHP interpreter: " + err);
                reject("Could not start PHP interpreter: " + err);
            }
        });
    }
}

assistant = null;

function registerAssistant() {
    if (assistant) {
        unregisterAssistant();
    }
    
    let event = nova.workspace.config.get("php.validate");
    if (!event) {
        return;
    }
    
    let options = {
        event: event
    };
    assistant = nova.assistants.registerIssueAssistant("php", new NovaPHPValidator(), options);
}

function unregisterAssistant() {
    if (assistant) {
        assistant.dispose()
        assistant = null;
    }
}

nova.workspace.config.onDidChange("php.validate", (newValue, oldValue) => {
    registerAssistant();
});

nova.workspace.config.onDidChange("php.interpreter", (newValue, oldValue) => {
    registerAssistant();
});

registerAssistant();

